@@ -49,8 +49,11 @@ static int __init probe_kernel_read(struct file *file, unsigned long offset,
 	set_fs(old_fs);
 	file->f_pos = pos;
 	return result;
-#else
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 14, 0)
 	return kernel_read(file, offset, addr, count);
+#else
+	loff_t pos = offset;
+	return kernel_read(file, addr, count, &pos);
 #endif
 }
 
